# coding: utf-8

# flake8: noqa
"""
    Verity471 Unified API

      - creds: 1.0.1
  - indicators: 1.0.0
  - malware: 1.0.0
  - reports: 1.0.0
  - sources: 1.0.2
  - actors: 1.0.1
  - watchers: 1.0.0
  - observables: 1.0.0
  - entities: 1.0.0
  - girs: 1.0.0


    The version of the OpenAPI document: 1.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from verity471.models.activity import Activity
from verity471.models.activity_location import ActivityLocation
from verity471.models.activity_response import ActivityResponse
from verity471.models.actor import Actor
from verity471.models.actor_object import ActorObject
from verity471.models.actor_stream_page import ActorStreamPage
from verity471.models.actor_subject_of_report import ActorSubjectOfReport
from verity471.models.admiralty_code import AdmiraltyCode
from verity471.models.all_malware_profiles import AllMalwareProfiles
from verity471.models.assessment import Assessment
from verity471.models.attachment_classification import AttachmentClassification
from verity471.models.attachment_data import AttachmentData
from verity471.models.author_actor1 import AuthorActor1
from verity471.models.bad_request import BadRequest
from verity471.models.bot_settings import BotSettings
from verity471.models.breach_alert_by_id_response import BreachAlertByIdResponse
from verity471.models.breach_alert_response import BreachAlertResponse
from verity471.models.breach_alerts_response_stream import BreachAlertsResponseStream
from verity471.models.chat_message_stream import ChatMessageStream
from verity471.models.chat_messages_streaming_page import ChatMessagesStreamingPage
from verity471.models.chat_room_message_stream import ChatRoomMessageStream
from verity471.models.chat_server_type import ChatServerType
from verity471.models.chat_server_type_stream import ChatServerTypeStream
from verity471.models.classification import Classification
from verity471.models.classification_response import ClassificationResponse
from verity471.models.confidence import Confidence
from verity471.models.confidence_level import ConfidenceLevel
from verity471.models.conflict import Conflict
from verity471.models.controller_url import ControllerUrl
from verity471.models.country_profile_response import CountryProfileResponse
from verity471.models.cred_credential_set_response import CredCredentialSetResponse
from verity471.models.cred_data_response import CredDataResponse
from verity471.models.cred_password_complexity_response import CredPasswordComplexityResponse
from verity471.models.cred_password_response import CredPasswordResponse
from verity471.models.cred_set_accessed_url_data_response import CredSetAccessedUrlDataResponse
from verity471.models.cred_set_data_response import CredSetDataResponse
from verity471.models.cred_set_statistics_response import CredSetStatisticsResponse
from verity471.models.cred_statistics_response import CredStatisticsResponse
from verity471.models.credential_occurrence_cred_response import CredentialOccurrenceCredResponse
from verity471.models.credential_occurrence_data_response import CredentialOccurrenceDataResponse
from verity471.models.cve_source import CveSource
from verity471.models.cvss import Cvss
from verity471.models.data_leak_site_file_listing_url import DataLeakSiteFileListingUrl
from verity471.models.data_leak_site_post1 import DataLeakSitePost1
from verity471.models.data_leak_site_post_item import DataLeakSitePostItem
from verity471.models.data_leak_site_post_thread import DataLeakSitePostThread
from verity471.models.data_leak_site_post_website import DataLeakSitePostWebsite
from verity471.models.data_leak_site_posts_streaming_page import DataLeakSitePostsStreamingPage
from verity471.models.encryption import Encryption
from verity471.models.entities import Entities
from verity471.models.entity import Entity
from verity471.models.entity_item import EntityItem
from verity471.models.entity_stream_page import EntityStreamPage
from verity471.models.entity_type import EntityType
from verity471.models.error_response import ErrorResponse
from verity471.models.error_response_girs import ErrorResponseGirs
from verity471.models.event_controller import EventController
from verity471.models.event_data import EventData
from verity471.models.event_tag import EventTag
from verity471.models.events_stream import EventsStream
from verity471.models.exploit_status import ExploitStatus
from verity471.models.file import File
from verity471.models.fintel_report_sub_type import FintelReportSubType
from verity471.models.fintel_reports_response_stream import FintelReportsResponseStream
from verity471.models.fintel_response import FintelResponse
from verity471.models.forbidden import Forbidden
from verity471.models.forum import Forum
from verity471.models.forum_object import ForumObject
from verity471.models.forums_posts_streaming_page import ForumsPostsStreamingPage
from verity471.models.forums_private_messages_streaming_page import ForumsPrivateMessagesStreamingPage
from verity471.models.forums_response1 import ForumsResponse1
from verity471.models.gir import GIR
from verity471.models.geo_ip import GeoIp
from verity471.models.geo_ip_observables import GeoIpObservables
from verity471.models.geopol_report_details_response import GeopolReportDetailsResponse
from verity471.models.geopol_report_sub_type import GeopolReportSubType
from verity471.models.geopol_reports_response_stream import GeopolReportsResponseStream
from verity471.models.get_cred_occurrence_response import GetCredOccurrenceResponse
from verity471.models.get_cred_occurrence_response_stream import GetCredOccurrenceResponseStream
from verity471.models.get_cred_response import GetCredResponse
from verity471.models.get_cred_response_stream import GetCredResponseStream
from verity471.models.get_cred_set_accessed_url_response import GetCredSetAccessedUrlResponse
from verity471.models.get_cred_set_accessed_url_response_stream import GetCredSetAccessedUrlResponseStream
from verity471.models.get_cred_set_response import GetCredSetResponse
from verity471.models.get_cred_set_response_stream import GetCredSetResponseStream
from verity471.models.get_watcher_group_response import GetWatcherGroupResponse
from verity471.models.get_watcher_group_response_wrapper import GetWatcherGroupResponseWrapper
from verity471.models.get_watcher_response import GetWatcherResponse
from verity471.models.get_watcher_response_wrapper import GetWatcherResponseWrapper
from verity471.models.gir_tree import GirTree
from verity471.models.girs_response import GirsResponse
from verity471.models.girs_tree_response import GirsTreeResponse
from verity471.models.highlight import Highlight
from verity471.models.highlight_watchers import HighlightWatchers
from verity471.models.href import Href
from verity471.models.im_server import ImServer
from verity471.models.image_type import ImageType
from verity471.models.indicator_data import IndicatorData
from verity471.models.indicators_stream import IndicatorsStream
from verity471.models.industries import Industries
from verity471.models.info_report_response import InfoReportResponse
from verity471.models.info_reports_response_stream import InfoReportsResponseStream
from verity471.models.info_stealer_response_option import InfoStealerResponseOption
from verity471.models.info_stealer_response_set import InfoStealerResponseSet
from verity471.models.integrations_event import IntegrationsEvent
from verity471.models.integrations_indicator import IntegrationsIndicator
from verity471.models.intelligence_estimate_response import IntelligenceEstimateResponse
from verity471.models.interest_level import InterestLevel
from verity471.models.internal_server_error import InternalServerError
from verity471.models.ipv4 import Ipv4
from verity471.models.isp import Isp
from verity471.models.isp_data import IspData
from verity471.models.kill_chain_phase import KillChainPhase
from verity471.models.link import Link
from verity471.models.link1 import Link1
from verity471.models.links import Links
from verity471.models.links_source import LinksSource
from verity471.models.links_watchers import LinksWatchers
from verity471.models.location import Location
from verity471.models.malware import Malware
from verity471.models.malware_family import MalwareFamily
from verity471.models.malware_report_response import MalwareReportResponse
from verity471.models.malware_reports_response_stream import MalwareReportsResponseStream
from verity471.models.motivation import Motivation
from verity471.models.not_found import NotFound
from verity471.models.notification_preference_type import NotificationPreferenceType
from verity471.models.notification_settings_response import NotificationSettingsResponse
from verity471.models.observable import Observable
from verity471.models.observable_stream_page import ObservableStreamPage
from verity471.models.observable_type import ObservableType
from verity471.models.patch_status import PatchStatus
from verity471.models.poc import Poc
from verity471.models.post_details1 import PostDetails1
from verity471.models.post_response1 import PostResponse1
from verity471.models.private_message_details1 import PrivateMessageDetails1
from verity471.models.private_message_response1 import PrivateMessageResponse1
from verity471.models.processing_status import ProcessingStatus
from verity471.models.recipient_domain import RecipientDomain
from verity471.models.redirect import Redirect
from verity471.models.report import Report
from verity471.models.report_attachment import ReportAttachment
from verity471.models.report_content import ReportContent
from verity471.models.report_entities import ReportEntities
from verity471.models.report_location import ReportLocation
from verity471.models.report_observables import ReportObservables
from verity471.models.report_response_stream import ReportResponseStream
from verity471.models.report_type import ReportType
from verity471.models.reporting_status import ReportingStatus
from verity471.models.reports_victim_response import ReportsVictimResponse
from verity471.models.revocation import Revocation
from verity471.models.risk_level import RiskLevel
from verity471.models.room_stream import RoomStream
from verity471.models.security_assessment import SecurityAssessment
from verity471.models.server_stream import ServerStream
from verity471.models.settings import Settings
from verity471.models.share_settings_response import ShareSettingsResponse
from verity471.models.significant_activity import SignificantActivity
from verity471.models.simplified_malware_profile import SimplifiedMalwareProfile
from verity471.models.source_link import SourceLink
from verity471.models.source_links import SourceLinks
from verity471.models.sources_links import SourcesLinks
from verity471.models.sources_response import SourcesResponse
from verity471.models.spot_report_response import SpotReportResponse
from verity471.models.spot_reports_response_stream import SpotReportsResponseStream
from verity471.models.streaming_alerts_response import StreamingAlertsResponse
from verity471.models.streaming_watcher_alert import StreamingWatcherAlert
from verity471.models.sub_forum_response1 import SubForumResponse1
from verity471.models.template import Template
from verity471.models.tension_point_response import TensionPointResponse
from verity471.models.thread_response1 import ThreadResponse1
from verity471.models.threat import Threat
from verity471.models.threat_data import ThreatData
from verity471.models.threat_info import ThreatInfo
from verity471.models.threat_rating import ThreatRating
from verity471.models.translation_status import TranslationStatus
from verity471.models.trigger import Trigger
from verity471.models.unauthorized import Unauthorized
from verity471.models.victim_response import VictimResponse
from verity471.models.vulnerabilities_report_details_response import VulnerabilitiesReportDetailsResponse
from verity471.models.vulnerabilities_report_details_response_stream import VulnerabilitiesReportDetailsResponseStream
from verity471.models.vulnerabilities_reports_response_stream import VulnerabilitiesReportsResponseStream
from verity471.models.vulnerability_status import VulnerabilityStatus
from verity471.models.watcher_group_type import WatcherGroupType
from verity471.models.yara_data import YaraData




import logging
import pycti
from stix2.exceptions import InvalidValueError
from stix2 import Indicator, Bundle, Relationship, KillChainPhase


from .. import author_identity, StixObjects
from .common import StixMapper, BaseMapper, MappingConfig
from ..constants import MARKING, PLATFORM_VERITY471
from ..sco import map_domain, map_url, map_ipv4, map_file, map_email_address
from ..sdo import map_malware


log = logging.getLogger(__name__)


@StixMapper.register(
    "indicators", lambda x: "indicators" in x and isinstance(x["indicators"], list)
)
@StixMapper.register(
    "indicator",
    lambda x: isinstance(x, dict)
    and (x.get("id") or "").startswith("malware-indicator--"),
)
class IndicatorsMapper(BaseMapper):

    mapping_configs = {
        "url": MappingConfig(
            entities_mapper=map_url,
            kwargs_extractor=lambda i: {"value": i["data"]["url"]},
            name_extractor=lambda i: i["data"]["url"],
            opencti_type="Url"
        ),
        "ipv4": MappingConfig(
            entities_mapper=map_ipv4,
            kwargs_extractor=lambda i: {
                "value": i["data"]["ipv4"]["ip_address"]
            },
            name_extractor=lambda i: i["data"]["ipv4"]["ip_address"],
            opencti_type="IPv4-Addr"
        ),
        "file": MappingConfig(
            entities_mapper=map_file,
            kwargs_extractor=lambda i: {
                "md5": i["data"]["file"]["md5"],
                "sha1": i["data"]["file"]["sha1"],
                "sha256": i["data"]["file"]["sha256"],
            },
            name_extractor=lambda i: i["data"]["file"]["sha256"],
            opencti_type="StixFile"
        ),
        "domain": MappingConfig(
            entities_mapper=map_domain,
            kwargs_extractor=lambda i: {
                "value": i["data"]["domain"]
            },
            name_extractor=lambda i: i["data"]["domain"],
            opencti_type="Domain-Name"
        ),
        "email": MappingConfig(
            entities_mapper=map_email_address,
            kwargs_extractor=lambda i: {
                "value": i["data"]["email"]
            },
            name_extractor=lambda i: i["data"]["email"],
            opencti_type="Email-Addr"
        ),
       "yara": MappingConfig(
            entities_mapper=lambda value=None: None,
            kwargs_extractor=lambda i: {"value": None},
            name_extractor=lambda i: None,
            opencti_type=None
        )
    }

    def map(self, source: dict) -> Bundle:
        container = StixObjects()
        items = (
            source.get("indicators") or []
            if "count" in source
            else [source]
        )
        for item in items:
            mapping_config = self.mapping_configs.get(item["type"])
            if not mapping_config:
                continue
            malware_family_name = item["threat"]["data"]["malware_family"]["name"]
            malware = map_malware(malware_family_name)
            labels = [malware_family_name, PLATFORM_VERITY471]
            try:
                labels.extend(self.get_girs_labels(item["classification"]["girs"]))
            except KeyError:
                pass
            custom_properties = {"x_opencti_main_observable_type": mapping_config.opencti_type}
            try:
                pattern = item["pattern"]
            except KeyError:
                log.warning("Can't get pattern for indicator %s", item.get("id"))
                continue
            if self.settings.ioc_opencti_score:
                custom_properties["x_opencti_score"] = self.settings.ioc_opencti_score
            
            indicator_kwargs = {
                "pattern_type": item["pattern_type"],
                "id": pycti.Indicator.generate_id(pattern),
                "pattern": pattern,
                "pattern_version": item["pattern_version"],
                "indicator_types": ["malicious-activity"],
                "valid_from": item["activity"]["first_seen_ts"],
                "valid_until": item.get("expiration_ts"),
                "created_by_ref": author_identity,
                "object_marking_refs": [MARKING],
                "name": mapping_config.name_extractor(item),
                "description": item.get("description"),
                "labels": labels,
                "confidence": item["confidence"],
                "custom_properties": custom_properties
            }
            if kill_chain_phases := item.get("kill_chain_phases"):
                indicator_kwargs["kill_chain_phases"] = [
                    KillChainPhase(**{**kw, 'phase_name': kw['phase_name'].replace('_', '-')})
                    for kw in kill_chain_phases
                ]
            try:
                indicator = Indicator(**indicator_kwargs)
            except InvalidValueError as e:
                log.warning("Can't map indicator `%s`: %s", item.get("id"), e)
                continue
            r1 = Relationship(
                id=pycti.StixCoreRelationship.generate_id(
                    relationship_type="indicates",
                    source_ref=indicator.id,
                    target_ref=malware.id),
                source_ref=indicator,
                relationship_type="indicates",
                target_ref=malware,
                created_by_ref=author_identity,
                labels=[PLATFORM_VERITY471],
                object_marking_refs=[MARKING]
            )

            for stix_object in [
                malware,
                indicator,
                r1,
                author_identity,
                MARKING,
            ]:
                container.add(stix_object)

            try:
                observable = mapping_config.entities_mapper(**mapping_config.kwargs_extractor(item))
            except InvalidValueError as e:
                log.warning("Can't map observable `%s`: %s", item.get('id'), e)
            else:
                if observable:
                    r2 = Relationship(
                        id=pycti.StixCoreRelationship.generate_id(
                            relationship_type="based-on",
                            source_ref=indicator.id,
                            target_ref=observable.id),
                        source_ref=indicator,
                        relationship_type="based-on",
                        target_ref=observable,
                        created_by_ref=author_identity,
                        labels=[PLATFORM_VERITY471],
                        object_marking_refs=[MARKING]
                    )
                    container.add(observable)
                    container.add(r2)

        if container:
            bundle = Bundle(*container.get(), allow_custom=True)
            return bundle



# flake8: noqa

# import apis into api package
from verity471.api.actors_api import ActorsApi
from verity471.api.alerts_api import AlertsApi
from verity471.api.credentials_api import CredentialsApi
from verity471.api.events_api import EventsApi
from verity471.api.girs_api import GIRsApi
from verity471.api.indicators_api import IndicatorsApi
from verity471.api.malware_api import MalwareApi
from verity471.api.reports_api import ReportsApi
from verity471.api.sources_api import SourcesApi
from verity471.api.watchers_api import WatchersApi
from verity471.api.entities_api import EntitiesApi
from verity471.api.observables_api import ObservablesApi




from stix2 import Malware, ThreatActor, Identity, Vulnerability
import pycti
from . import author_identity
from .constants import MARKING, PLATFORM_VERITY471



def map_malware(value: str, *args, **kwargs) -> Malware:
    return Malware(
        id=pycti.Malware.generate_id(value),
        name=value,
        is_family=True,
        created_by_ref=author_identity,
        labels=[PLATFORM_VERITY471],
        object_marking_refs=[MARKING],  
    )

def map_threat_actor(value: str, description: str = None, *args, **kwargs) -> ThreatActor:
    return ThreatActor(
        id=pycti.ThreatActorIndividual.generate_id(value),
        name = value,
        description = description,
        resource_level="individual",
        created_by_ref=author_identity,
        labels=[PLATFORM_VERITY471],
        object_marking_refs=[MARKING],
)


def map_vulnerability(value: str, *args, **kwargs) -> Vulnerability:
    return Vulnerability(
        id=pycti.Vulnerability.generate_id(value),
        name=value,
        created_by_ref=author_identity,
        labels=[PLATFORM_VERITY471],
        object_marking_refs=[MARKING],
    )


def map_organization(value: str, url=None, *args, **kwargs) -> Identity:
    return Identity(
        id=pycti.Identity.generate_id(value, identity_class="organization"),
        name = value,
        contact_information=url,
        identity_class="organization",
        created_by_ref=author_identity,
        labels=[PLATFORM_VERITY471],
        object_marking_refs=[MARKING],
)



import json
from datetime import datetime
from unittest.mock import MagicMock, patch

import pytest
import verity471

from .conftest import PREFIX, read_fixture


configuration = verity471.Configuration()


def normalize_for_comparison(obj):
    """Normalize a dictionary by converting datetime objects to ISO strings."""
    if isinstance(obj, datetime):
        # Convert datetime to ISO format with 'Z' suffix for UTC
        iso_str = obj.isoformat()
        # Replace +00:00 with Z to match the JSON format
        if iso_str.endswith('+00:00'):
            return iso_str[:-6] + 'Z'
        # If timezone-naive, assume UTC and add Z
        elif obj.tzinfo is None:
            return iso_str + 'Z'
        else:
            return iso_str
    elif isinstance(obj, dict):
        return {k: normalize_for_comparison(v) for k, v in obj.items()}
    elif isinstance(obj, list):
        return [normalize_for_comparison(item) for item in obj]
    else:
        return obj

test_params = {
    'IndicatorsApi:get_indicators_stream': ('IndicatorsApi', 'get_indicators_stream', {'size': 1}, 'IndicatorStreamResponse', 'https://api.intel471.cloud/integrations/indicators/v1/indicators/stream?size=1'),
    'IndicatorsApi:get_indicator_by_id': ('IndicatorsApi', 'get_indicator_by_id', {'id': 'malware-indicator--00000000-0000-0000-0000-000000000000'}, 'IntegrationsIndicator', 'https://api.intel471.cloud/integrations/indicators/v1/indicators/malware-indicator--00000000-0000-0000-0000-000000000000'),
    'EventsApi:get_events_stream': ('EventsApi', 'get_events_stream', {'size': 1}, 'EventsStreamResponse', 'https://api.intel471.cloud/integrations/malware-intel/v1/events/stream?size=1'),
    'EventsApi:get_event_by_id': ('EventsApi', 'get_event_by_id', {'id': 'malware-event--00000000-0000-0000-0000-000000000000'}, 'IntegrationsEvent', 'https://api.intel471.cloud/integrations/malware-intel/v1/events/malware-event--00000000-0000-0000-0000-000000000000'),
    'GIRsApi:get_list_of_girs_in_a_hierarchical_structure': ('GIRsApi', 'get_list_of_girs_in_a_hierarchical_structure', {}, 'GirsTreeResponse', 'https://api.intel471.cloud/integrations/girs/v1/girs/tree'),
    'MalwareApi:get_malware_list': ('MalwareApi', 'get_malware_list', {'size': 1}, 'AllMalwareProfilesResponse', 'https://api.intel471.cloud/integrations/malware-intel/v1/malware?size=1'),
    'MalwareApi:get_malware_family_by_id': ('MalwareApi', 'get_malware_family_by_id', {'id': 'malware-family--00000000-0000-0000-0000-000000000000'}, 'SimplifiedMalwareProfile', 'https://api.intel471.cloud/integrations/malware-intel/v1/malware/malware-family--00000000-0000-0000-0000-000000000000'),
    'CredentialsApi:get_credential_sets_accessed_urls_stream': ('CredentialsApi', 'get_credential_sets_accessed_urls_stream', {'size': 1}, 'GetCredSetAccessedUrlResponseStream', 'https://api.intel471.cloud/integrations/creds/v1/credential-sets/accessed-urls/stream?size=1'),
    'CredentialsApi:get_credential_sets_id': ('CredentialsApi', 'get_credential_sets_id', {'id': 'cred-set--84c92b87-ed31-5103-8101-97b87c03a47a'}, 'GetCredSetResponse', 'https://api.intel471.cloud/integrations/creds/v1/credential-sets/cred-set--84c92b87-ed31-5103-8101-97b87c03a47a'),
    'CredentialsApi:get_credential_sets_stream': ('CredentialsApi', 'get_credential_sets_stream', {'size': 1}, 'GetCredSetResponseStream', 'https://api.intel471.cloud/integrations/creds/v1/credential-sets/stream?size=1'),
    'CredentialsApi:get_credentials_id': ('CredentialsApi', 'get_credentials_id', {'id': 'cred--3f2abe55-8469-59db-b25a-f8268eb31f34'}, 'GetCredResponse', 'https://api.intel471.cloud/integrations/creds/v1/credentials/cred--3f2abe55-8469-59db-b25a-f8268eb31f34'),
    'CredentialsApi:get_credentials_occurrences_id': ('CredentialsApi', 'get_credentials_occurrences_id', {'id': 'cred-occurrence--1edd10b4-e75d-5aa2-9b43-5e08c6a682cb'}, 'GetCredOccurrenceResponse', 'https://api.intel471.cloud/integrations/creds/v1/credentials/occurrences/cred-occurrence--1edd10b4-e75d-5aa2-9b43-5e08c6a682cb'),
    'CredentialsApi:get_credentials_occurrences_stream': ('CredentialsApi', 'get_credentials_occurrences_stream', {'size': 1}, 'GetCredOccurrenceResponseStream', 'https://api.intel471.cloud/integrations/creds/v1/credentials/occurrences/stream?size=1'),
    'CredentialsApi:get_credentials_stream': ('CredentialsApi', 'get_credentials_stream', {'size': 1}, 'GetCredResponseStream', 'https://api.intel471.cloud/integrations/creds/v1/credentials/stream?size=1'),
    'ReportsApi:get_reports_breach_alert_id': ('ReportsApi', 'get_reports_breach_alert_id', {'id': 'report--fbbb23d6-713f-5f41-9ee4-45b3ff027017'}, 'BreachAlertByIdResponse', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/breach-alert/report--fbbb23d6-713f-5f41-9ee4-45b3ff027017'),
    'ReportsApi:get_reports_breach_alert_stream': ('ReportsApi', 'get_reports_breach_alert_stream', {'size': 1}, 'BreachAlertsResponseStream', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/breach-alert/stream?size=1'),
    'ReportsApi:get_reports_fintel_id': ('ReportsApi', 'get_reports_fintel_id', {'id': 'report--e71d387f-325e-5bfc-a43d-143876c6cfc0'}, 'FintelResponse', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/fintel/report--e71d387f-325e-5bfc-a43d-143876c6cfc0'),
    'ReportsApi:get_reports_fintel_stream': ('ReportsApi', 'get_reports_fintel_stream', {'size': 1}, 'FintelReportsResponseStream', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/fintel/stream?size=1'),
    'ReportsApi:get_reports_geopol_id': ('ReportsApi', 'get_reports_geopol_id', {'id': 'report--464ad694-6e92-5983-93f2-f0a7f4d84d7e'}, 'GeopolReportDetailsResponse', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/geopol/report--464ad694-6e92-5983-93f2-f0a7f4d84d7e'),
    'ReportsApi:get_reports_geopol_stream': ('ReportsApi', 'get_reports_geopol_stream', {'size': 1}, 'GeopolReportsResponseStream', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/geopol/stream?size=1'),
    'ReportsApi:get_reports_info_id': ('ReportsApi', 'get_reports_info_id', {'id': 'report--1d4f77cb-ee3b-5ec2-9291-8cf9356bdfb8'}, 'InfoReportResponse', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/info/report--1d4f77cb-ee3b-5ec2-9291-8cf9356bdfb8'),
    'ReportsApi:get_reports_info_stream': ('ReportsApi', 'get_reports_info_stream', {'size': 1}, 'InfoReportsResponseStream', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/info/stream?size=1'),
    'ReportsApi:get_reports_malware_id': ('ReportsApi', 'get_reports_malware_id', {'id': 'report--8d11b63b-f7d6-5061-bb17-290ee5af9464'}, 'MalwareReportResponse', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/malware/report--8d11b63b-f7d6-5061-bb17-290ee5af9464'),
    'ReportsApi:get_reports_malware_stream': ('ReportsApi', 'get_reports_malware_stream', {'size': 1}, 'MalwareReportsResponseStream', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/malware/stream?size=1'),
    'ReportsApi:get_reports_spot_id': ('ReportsApi', 'get_reports_spot_id', {'id': 'report--cb89fbf0-4a56-5f0c-8bd4-166b2115362f'}, 'SpotReportResponse', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/spot/report--cb89fbf0-4a56-5f0c-8bd4-166b2115362f'),
    'ReportsApi:get_reports_spot_stream': ('ReportsApi', 'get_reports_spot_stream', {'size': 1}, 'SpotReportsResponseStream', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/spot/stream?size=1'),
    'ReportsApi:get_reports_stream': ('ReportsApi', 'get_reports_stream', {'size': 1}, 'ReportResponseStream', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/stream?size=1'),
    'ReportsApi:get_reports_vulnerability_id': ('ReportsApi', 'get_reports_vulnerability_id', {'id': 'vulnerability--451a1d7b-e555-5c25-bb21-f544d2ce6997'}, 'VulnerabilitiesReportDetailsResponse', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/vulnerability/vulnerability--451a1d7b-e555-5c25-bb21-f544d2ce6997'),
    'ReportsApi:get_reports_vulnerability_stream': ('ReportsApi', 'get_reports_vulnerability_stream', {'size': 1}, 'VulnerabilitiesReportsResponseStream', 'https://api.intel471.cloud/integrations/intel-report/v1/reports/vulnerability/stream?size=1'),
    # 'SourcesApi:get_data_leak_sites_file_listings_id': ('SourcesApi', 'get_data_leak_sites_file_listings_id', {'id': 'myid-1234'}, 'DataLeakSiteFileListingResponse', 'https://api.intel471.cloud/integrations/sources/v1/data-leak-sites/file-listings/myid-1234'),
    'SourcesApi:get_data_leak_sites_posts_stream': ('SourcesApi', 'get_data_leak_sites_posts_stream', {'size': 1}, 'DataLeakSitePostsStreamingPage', 'https://api.intel471.cloud/integrations/sources/v1/data-leak-sites/posts/stream?size=1'),
    'SourcesApi:get_forums_posts_post_id': ('SourcesApi', 'get_forums_posts_post_id', {'post_id': 'post--44a97352-e0bf-537a-8b51-13e16992586b'}, 'PostDetails1', 'https://api.intel471.cloud/integrations/sources/v1/forums/posts/post--44a97352-e0bf-537a-8b51-13e16992586b'),
    'SourcesApi:get_forums_posts_stream': ('SourcesApi', 'get_forums_posts_stream', {'size': 1}, 'ForumsPostsStreamingPage', 'https://api.intel471.cloud/integrations/sources/v1/forums/posts/stream?size=1'),
    'SourcesApi:get_forums_private_messages_private_message_id': ('SourcesApi', 'get_forums_private_messages_private_message_id', {'private_message_id': 'private-message--d2c24f11-ed5a-5d6c-b4cc-83a5ff96c0b4'}, 'PrivateMessageDetails1', 'https://api.intel471.cloud/integrations/sources/v1/forums/private-messages/private-message--d2c24f11-ed5a-5d6c-b4cc-83a5ff96c0b4'),
    'SourcesApi:get_forums_private_messages_stream': ('SourcesApi', 'get_forums_private_messages_stream', {'size': 1}, 'ForumsPrivateMessagesStreamingPage', 'https://api.intel471.cloud/integrations/sources/v1/forums/private-messages/stream?size=1'),
    'SourcesApi:get_messaging_services_messages_message_id': ('SourcesApi', 'get_messaging_services_messages_message_id', {'message_id': 'message--da2a22d1-4d3e-5b79-b557-c275453f31f9'}, 'ChatRoomMessageStream', 'https://api.intel471.cloud/integrations/sources/v1/messaging-services/messages/message--da2a22d1-4d3e-5b79-b557-c275453f31f9'),
    'SourcesApi:get_messaging_services_messages_stream': ('SourcesApi', 'get_messaging_services_messages_stream', {'size': 1}, 'ChatMessagesStreamingPage', 'https://api.intel471.cloud/integrations/sources/v1/messaging-services/messages/stream?size=1'),
    'EntitiesApi:get_entities_stream': ('EntitiesApi', 'get_entities_stream', {'entity': 'intel.com', 'size': 1}, 'EntitiesStreamResponse', 'https://api.intel471.cloud/integrations/entities/v1/entities/stream?entity=intel.com&size=1'),
    'ObservablesApi:get_observables_stream': ('ObservablesApi', 'get_observables_stream', {'observable': 'domain'}, 'ObservablesStreamResponse', 'https://api.intel471.cloud/integrations/observables/v1/observables/stream?observable=domain'),
    'AlertsApi:get_alerts_stream': ('AlertsApi', 'get_alerts_stream', {'size': 1}, 'AlertsStreamResponse', 'https://api.intel471.cloud/integrations/watchers/v1/alerts/stream?size=1'),
    'WatchersApi:get_watchers': ('WatchersApi', 'get_watchers', {}, 'WatchersResponse', 'https://api.intel471.cloud/integrations/watchers/v1/watchers'),
    'WatchersApi:get_watcher_groups': ('WatchersApi', 'get_watcher_groups', {}, 'WatcherGroupsResponse', 'https://api.intel471.cloud/integrations/watchers/v1/watcher-groups'),
    'ActorsApi:get_actors_stream': ('ActorsApi', 'get_actors_stream', {'actor': 'yalishanda', 'size': 100}, 'ActorsStreamResponse', 'https://api.intel471.cloud/integrations/actors/v1/actors/stream?actor=yalishanda&size=100'),
}

@patch('verity471.rest.RESTClientObject')
@pytest.mark.parametrize('api_cls_name, method_name, kwargs, filename, query_url', test_params.values(), ids=test_params.keys())
def test_api_responses(rest_client_class_mock, api_cls_name, method_name, kwargs, filename, query_url):
    rest_client_response = MagicMock(name='rest_client_response')
    rest_client_response.status = 200
    rest_client_response.reason = 'OK'
    rest_client_response.headers = {'content-type': 'application/json; charset=utf-8'}
    response = read_fixture(f'{PREFIX}/fixtures/api_responses/{filename}.json')
    rest_client_response.data = json.dumps(response).encode('utf-8')

    rest_client_instance_mock = MagicMock(name='rest_client_instance')
    rest_client_instance_mock.request.return_value = rest_client_response

    rest_client_class_mock.side_effect = [rest_client_instance_mock]

    with verity471.ApiClient(configuration) as api_client:
        api_instance = getattr(verity471, api_cls_name)(api_client)
        api_response = getattr(api_instance, method_name)(**kwargs)

        assert rest_client_instance_mock.request.call_args_list[0][0][1] == query_url
        normalized_response = normalize_for_comparison(api_response.to_dict())
        assert normalized_response == response



# coding: utf-8

"""
    Verity471 Unified API

      - creds: 1.0.1
  - indicators: 1.0.0
  - malware: 1.0.0
  - reports: 1.0.0
  - sources: 1.0.2
  - actors: 1.0.1
  - watchers: 1.0.0
  - observables: 1.0.0
  - entities: 1.0.0
  - girs: 1.0.0


    The version of the OpenAPI document: 1.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from verity471.models.bot_settings import BotSettings
from verity471.models.controller_url import ControllerUrl
from verity471.models.encryption import Encryption
from verity471.models.event_controller import EventController
from verity471.models.file import File
from verity471.models.location import Location
from verity471.models.recipient_domain import RecipientDomain
from verity471.models.redirect import Redirect
from verity471.models.settings import Settings
from verity471.models.template import Template
from verity471.models.trigger import Trigger
from typing import Optional, Set, TYPE_CHECKING
from typing_extensions import Self

if TYPE_CHECKING:
    # Only for type checkers; does not run at runtime.
    from verity471.verity_stix import STIXMapperSettings


class EventData(BaseModel):
    """
    Malware event data.
    """ # noqa: E501
    arguments: Optional[List[StrictStr]] = Field(default=None, description="Arguments.")
    attack_targets: Optional[List[Dict[str, StrictStr]]] = Field(default=None, description="Attack targets.")
    attack_type: Optional[StrictStr] = Field(default=None, description="Attack type.")
    bot_settings: Optional[BotSettings] = Field(default=None, description="An object containing varying data types showing malware bot settings data. Contains any of but not limited the following fields: `exit_country`, `encryption`.")
    command: Optional[StrictStr] = Field(default=None, description="Command.")
    component_type: Optional[StrictStr] = Field(default=None, description="Type of component i.e. `CORE`.")
    config_file: Optional[File] = Field(default=None, description="Config file.")
    controller: Optional[EventController] = Field(default=None, description="Object containing the `url` and `ipv4` of a `controller`.")
    controllers: Optional[List[ControllerUrl]] = Field(default=None, description="An array of objects, each containing an individual controller's url.")
    encryption: Optional[List[Encryption]] = Field(default=None, description="An array of `encryption` meta data.")
    exfil_location: Optional[StrictStr] = Field(default=None, description="Contains the url location of the exfiltration event.")
    file: Optional[File] = Field(default=None, description="Object containing fields of the `file`'s hashes (`md5`, `sha1`, `sha256`) and file `type` and `size`.")
    function: Optional[StrictStr] = Field(default=None, description="Function name.")
    inject_type: Optional[StrictStr] = Field(default=None, description="Inject type.")
    location: Optional[Location] = Field(default=None, description="The `url` object of the location of the event.")
    parameters: Optional[List[Dict[str, StrictStr]]] = Field(default=None, description="Parameters.")
    plugin_name: Optional[StrictStr] = Field(default=None, description="Plugin's name.")
    plugin_type: Optional[StrictStr] = Field(default=None, description="Type of plugin. i.e. `REMOTE_ACCESS`, `CREDENTIAL_STEALER`, `OTHER`.")
    recipient_domains: Optional[List[RecipientDomain]] = Field(default=None, description="Recipient domains.")
    recipient_file: Optional[File] = Field(default=None, description="Recipient file.")
    redirects: Optional[List[Redirect]] = Field(default=None, description="An array of redirects.")
    senders: Optional[List[StrictStr]] = Field(default=None, description="Senders.")
    service_type: Optional[StrictStr] = Field(default=None, description="Type of service.")
    settings: Optional[Settings] = Field(default=None, description="An array of event related `settings` objects containing any of but not limited the following fields: `plugin_location`, `bot_version`, `compaign_id`, etc.")
    target_type: Optional[StrictStr] = Field(default=None, description="Type of target.")
    template: Optional[Template] = Field(default=None, description="Template information.")
    triggers: Optional[List[Trigger]] = Field(default=None, description="An array of objects, each containing the field `trigger`.")
    __properties: ClassVar[List[str]] = ["arguments", "attack_targets", "attack_type", "bot_settings", "command", "component_type", "config_file", "controller", "controllers", "encryption", "exfil_location", "file", "function", "inject_type", "location", "parameters", "plugin_name", "plugin_type", "recipient_domains", "recipient_file", "redirects", "senders", "service_type", "settings", "target_type", "template", "triggers"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_stix(self, settings: Optional["STIXMapperSettings"] = None):
        try:
            from verity471.verity_stix.mappers.common import StixMapper
        except ImportError as e:
            raise ImportError(
                "STIX support is an optional feature. "
                "Install with: pip install 'verity471[stix]'"
            ) from e
        stix_mapper = StixMapper(settings)
        return stix_mapper.map(self.to_dict())

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EventData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of bot_settings
        if self.bot_settings:
            _dict['bot_settings'] = self.bot_settings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of config_file
        if self.config_file:
            _dict['config_file'] = self.config_file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of controller
        if self.controller:
            _dict['controller'] = self.controller.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in controllers (list)
        _items = []
        if self.controllers:
            for _item_controllers in self.controllers:
                if _item_controllers:
                    _items.append(_item_controllers.to_dict())
            _dict['controllers'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in encryption (list)
        _items = []
        if self.encryption:
            for _item_encryption in self.encryption:
                if _item_encryption:
                    _items.append(_item_encryption.to_dict())
            _dict['encryption'] = _items
        # override the default output from pydantic by calling `to_dict()` of file
        if self.file:
            _dict['file'] = self.file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of location
        if self.location:
            _dict['location'] = self.location.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in recipient_domains (list)
        _items = []
        if self.recipient_domains:
            for _item_recipient_domains in self.recipient_domains:
                if _item_recipient_domains:
                    _items.append(_item_recipient_domains.to_dict())
            _dict['recipient_domains'] = _items
        # override the default output from pydantic by calling `to_dict()` of recipient_file
        if self.recipient_file:
            _dict['recipient_file'] = self.recipient_file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in redirects (list)
        _items = []
        if self.redirects:
            for _item_redirects in self.redirects:
                if _item_redirects:
                    _items.append(_item_redirects.to_dict())
            _dict['redirects'] = _items
        # override the default output from pydantic by calling `to_dict()` of settings
        if self.settings:
            _dict['settings'] = self.settings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of template
        if self.template:
            _dict['template'] = self.template.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in triggers (list)
        _items = []
        if self.triggers:
            for _item_triggers in self.triggers:
                if _item_triggers:
                    _items.append(_item_triggers.to_dict())
            _dict['triggers'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EventData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "arguments": obj.get("arguments"),
            "attack_targets": obj.get("attack_targets"),
            "attack_type": obj.get("attack_type"),
            "bot_settings": BotSettings.from_dict(obj["bot_settings"]) if obj.get("bot_settings") is not None else None,
            "command": obj.get("command"),
            "component_type": obj.get("component_type"),
            "config_file": File.from_dict(obj["config_file"]) if obj.get("config_file") is not None else None,
            "controller": EventController.from_dict(obj["controller"]) if obj.get("controller") is not None else None,
            "controllers": [ControllerUrl.from_dict(_item) for _item in obj["controllers"]] if obj.get("controllers") is not None else None,
            "encryption": [Encryption.from_dict(_item) for _item in obj["encryption"]] if obj.get("encryption") is not None else None,
            "exfil_location": obj.get("exfil_location"),
            "file": File.from_dict(obj["file"]) if obj.get("file") is not None else None,
            "function": obj.get("function"),
            "inject_type": obj.get("inject_type"),
            "location": Location.from_dict(obj["location"]) if obj.get("location") is not None else None,
            "parameters": obj.get("parameters"),
            "plugin_name": obj.get("plugin_name"),
            "plugin_type": obj.get("plugin_type"),
            "recipient_domains": [RecipientDomain.from_dict(_item) for _item in obj["recipient_domains"]] if obj.get("recipient_domains") is not None else None,
            "recipient_file": File.from_dict(obj["recipient_file"]) if obj.get("recipient_file") is not None else None,
            "redirects": [Redirect.from_dict(_item) for _item in obj["redirects"]] if obj.get("redirects") is not None else None,
            "senders": obj.get("senders"),
            "service_type": obj.get("service_type"),
            "settings": Settings.from_dict(obj["settings"]) if obj.get("settings") is not None else None,
            "target_type": obj.get("target_type"),
            "template": Template.from_dict(obj["template"]) if obj.get("template") is not None else None,
            "triggers": [Trigger.from_dict(_item) for _item in obj["triggers"]] if obj.get("triggers") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Verity471 Unified API

      - creds: 1.0.1
  - indicators: 1.0.0
  - malware: 1.0.0
  - reports: 1.0.0
  - sources: 1.0.2
  - actors: 1.0.1
  - watchers: 1.0.0
  - observables: 1.0.0
  - entities: 1.0.0
  - girs: 1.0.0


    The version of the OpenAPI document: 1.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from verity471.models.attachment_classification import AttachmentClassification
from verity471.models.highlight import Highlight
from verity471.models.processing_status import ProcessingStatus
from verity471.models.reporting_status import ReportingStatus
from typing import Optional, Set, TYPE_CHECKING
from typing_extensions import Self

if TYPE_CHECKING:
    # Only for type checkers; does not run at runtime.
    from verity471.verity_stix import STIXMapperSettings


class AttachmentData(BaseModel):
    """
    AttachmentData
    """ # noqa: E501
    attachment_highlights: Optional[List[StrictStr]] = None
    attachment_original_url: Optional[StrictStr] = None
    classification: Optional[AttachmentClassification] = None
    dimensions: Optional[StrictStr] = None
    file_available: StrictBool
    file_hash: StrictStr
    file_name: StrictStr
    file_size: StrictInt
    file_url: Optional[StrictStr] = None
    highlights: Optional[List[Highlight]] = None
    id: StrictStr
    is_not_image: StrictBool
    mime_type: StrictStr
    original_height: Optional[StrictInt] = None
    original_width: Optional[StrictInt] = None
    processing_status: ProcessingStatus
    recognized_logos: Optional[StrictStr] = None
    recognized_text: Optional[StrictStr] = None
    reporting_status: ReportingStatus
    source_entity_id: StrictStr
    thumbnail_available: StrictBool
    thumbnail_height: Optional[StrictInt] = None
    thumbnail_width: Optional[StrictInt] = None
    webp_available: StrictBool
    __properties: ClassVar[List[str]] = ["attachment_highlights", "attachment_original_url", "classification", "dimensions", "file_available", "file_hash", "file_name", "file_size", "file_url", "highlights", "id", "is_not_image", "mime_type", "original_height", "original_width", "processing_status", "recognized_logos", "recognized_text", "reporting_status", "source_entity_id", "thumbnail_available", "thumbnail_height", "thumbnail_width", "webp_available"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_stix(self, settings: Optional["STIXMapperSettings"] = None):
        try:
            from verity471.verity_stix.mappers.common import StixMapper
        except ImportError as e:
            raise ImportError(
                "STIX support is an optional feature. "
                "Install with: pip install 'verity471[stix]'"
            ) from e
        stix_mapper = StixMapper(settings)
        return stix_mapper.map(self.to_dict())

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AttachmentData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in highlights (list)
        _items = []
        if self.highlights:
            for _item_highlights in self.highlights:
                if _item_highlights:
                    _items.append(_item_highlights.to_dict())
            _dict['highlights'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AttachmentData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "attachment_highlights": obj.get("attachment_highlights"),
            "attachment_original_url": obj.get("attachment_original_url"),
            "classification": obj.get("classification"),
            "dimensions": obj.get("dimensions"),
            "file_available": obj.get("file_available"),
            "file_hash": obj.get("file_hash"),
            "file_name": obj.get("file_name"),
            "file_size": obj.get("file_size"),
            "file_url": obj.get("file_url"),
            "highlights": [Highlight.from_dict(_item) for _item in obj["highlights"]] if obj.get("highlights") is not None else None,
            "id": obj.get("id"),
            "is_not_image": obj.get("is_not_image"),
            "mime_type": obj.get("mime_type"),
            "original_height": obj.get("original_height"),
            "original_width": obj.get("original_width"),
            "processing_status": obj.get("processing_status"),
            "recognized_logos": obj.get("recognized_logos"),
            "recognized_text": obj.get("recognized_text"),
            "reporting_status": obj.get("reporting_status"),
            "source_entity_id": obj.get("source_entity_id"),
            "thumbnail_available": obj.get("thumbnail_available"),
            "thumbnail_height": obj.get("thumbnail_height"),
            "thumbnail_width": obj.get("thumbnail_width"),
            "webp_available": obj.get("webp_available")
        })
        return _obj





import re

from stix2 import TLP_AMBER

REMOVE_HTML_REGEX = re.compile(r"<.*?>")
X_OPENCTI_CREATED_BY = "x_opencti_created_by_ref"
X_OPENCTI_LABELS = "x_opencti_labels"
MARKING = TLP_AMBER
INTEL_471 = "Intel 471"
PLATFORM_VERITY471 = "platform:verity471"



# coding: utf-8

"""
    Verity471 Unified API

      - creds: 1.0.1
  - indicators: 1.0.0
  - malware: 1.0.0
  - reports: 1.0.0
  - sources: 1.0.2
  - actors: 1.0.1
  - watchers: 1.0.0
  - observables: 1.0.0
  - entities: 1.0.0
  - girs: 1.0.0


    The version of the OpenAPI document: 1.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ChatServerType(str, Enum):
    """
    ChatServerType
    """

    """
    allowed enum values
    """
    TELEGRAM = 'Telegram'
    DISCORD = 'Discord'
    IRC = 'IRC'
    WHATSAPP = 'WhatsApp'
    QQ = 'QQ'
    ICQ = 'ICQ'
    MATRIX = 'Matrix'
    SIGNAL = 'Signal'
    UNKNOWN = 'UNKNOWN'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ChatServerType from a JSON string"""
        return cls(json.loads(json_str))





import datetime
import logging
import re
from enum import Enum
from typing import List, NamedTuple, Union, Callable

from pytz import UTC
from stix2 import Bundle, ExternalReference, Report, ThreatActor

from verity471.verity_stix.exceptions import VerityStixException
from .entities import EntitiesMapper

from .. import STIXMapperSettings, author_identity, StixObjects
from .common import BaseMapper, StixMapper
from ..constants import INTEL_471, MARKING, PLATFORM_VERITY471, REMOVE_HTML_REGEX
from ..sdo import map_organization


log = logging.getLogger(__name__)


class ReportType(Enum):
    INFOREP = "inforep"
    FINTEL = "fintel"
    BREACH_ALERT = "breach_alert"
    SPOTREP = "spotrep"
    MALWARE = "malware"
    GEOPOL = "geopol"


REPORT_SUBTYPE_ACTOR_PROFILE = "actor_profile"


class ReportSettings(NamedTuple):
    method_name: str
    portal_url_fragment: str
    # either JSON path to the field or a function that extracts value from provided source
    description_path_or_extractor: Union[str, Callable]
    entities_path_or_extractor: Union[str, Callable]
    victims_path: str
    links_path: str
    contents_paths: Union[List[str], None] = None



@StixMapper.register(
    "reports",
    lambda x: isinstance(x.get("reports"), list) and "fintel_report_count" not in x,
)
@StixMapper.register(
    "report",
    lambda x: isinstance(x, dict) and (x.get("id") or "").startswith("report--"),
)
class ReportMapper(BaseMapper):
    REPORTS_API_CLASS = "ReportsApi"
    reports_settings = {
        ReportType.FINTEL: ReportSettings(
            method_name="get_reports_fintel_id",
            portal_url_fragment="intelligence/fintelReportView",
            # There's no summary or anything similar. Try to extract contents of the first
            # paragraph <h2>...</h2><p>get-this</p>...
            description_path_or_extractor=lambda src: re.split(r'</?p>', re.sub(r'^.*?<p>', '', src.get("body") or ""))[0],
            entities_path_or_extractor="entities",
            victims_path="victims",
            links_path="sources",
            contents_paths=["body"]
        ),
        ReportType.INFOREP: ReportSettings(
            method_name="get_reports_info_id",
            portal_url_fragment="intelligence/infoReportView",
            description_path_or_extractor="executive_summary",
            entities_path_or_extractor="entities",
            victims_path="victims",
            links_path="sources",
            contents_paths=["executive_summary", "researcher_comments", "body_translated", "body", "source_characterization"]
        ),
        ReportType.BREACH_ALERT: ReportSettings(
            method_name="get_reports_breach_alert_id",
            portal_url_fragment="intelligence/breachAlertReportView",
            description_path_or_extractor="body",
            entities_path_or_extractor="entities",
            victims_path="victims",
            links_path="sources"
        ),
        ReportType.SPOTREP: ReportSettings(
            method_name="get_reports_spot_id",
            portal_url_fragment="intelligence/spotReportView",
            description_path_or_extractor="body",
            entities_path_or_extractor="entities",
            victims_path="victims",
            links_path="sources"
        ),
        ReportType.MALWARE: ReportSettings(
            method_name="get_reports_malware_id",
            portal_url_fragment="intelligence/malwareReportView",
            description_path_or_extractor=lambda src: (re.search(r'<p>(.*?)</p>', src.get("body") or "", flags=re.S) or [None, ""])[1],
            entities_path_or_extractor=lambda src: [{"type": "MalwareFamily", "value": src.get("threat", {}).get("family")}],
            victims_path="",
            links_path="",
            contents_paths=["body"]
        ),
        # No entities in geopol. Map Locations (also for other types)
        ReportType.GEOPOL: ReportSettings(
            method_name="get_reports_geopol_id",
            portal_url_fragment="geopol/geopolReportView",
            description_path_or_extractor=lambda src: (re.search(r'<p>(.*?)</p>', src.get("body") or "", flags=re.S) or [None, ""])[1],
            entities_path_or_extractor="entities",
            victims_path="",
            links_path="",
            contents_paths=["body"]
        )
    }

    def __init__(self, settings: STIXMapperSettings):
        super().__init__(settings)
        self.entities_mapper = EntitiesMapper()
        self.cache = {}

    def map(self, source: dict) -> Union[Bundle, None]:
        """
        Main entrypoint for mapping responses from /report, /breachAlerts and /spotReports endpoints
        """
        is_report_by_id = False
        if "reports" in source and isinstance(source["reports"], list):
            items = source["reports"]
        else:
            is_report_by_id = True
            items = [source]

        stix_objects = StixObjects()
        for item in items:
            report_type = self._get_type(item)
            if not is_report_by_id and self._is_full_report_required(item):
                # Search reports APIs might return a shortened version of a report:
                # - Some fields might be absent -> then `is_truncated=true` flag is present
                # - If there are images in the report, they will be present as references in text,
                #   not inline base64 representation
                # Full version with inline images is available only when getting individual
                # report by ID with `include_inline_images=true` flag
                stix_objects.extend(self._fetch_and_map_report(report_type, item["id"]).get())
            else:
                stix_objects.extend(self._map_report(item).get())
        if stix_objects:
            bundle = Bundle(*stix_objects.get(), allow_custom=True)
            return bundle

    def _map_report(self, source: dict, object_refs: StixObjects = None) -> StixObjects:
        """
        Map report in the format that is used when getting a report by ID.
        In case of FINTEL and INFOREP (/reports endpoint) there will be extra (possible big) fields.
        Breach alert and Spot report look the same in their long and short representation
        """
        if not object_refs:
            object_refs = StixObjects()
        if entities := self._get_entities(source):
            object_refs.extend(entities.get())
        if victims := self._get_victims(source):
            object_refs.extend(victims.get())
        if not object_refs:
            object_refs.extend([author_identity])

        report_type: ReportType = self._get_type(source)
        stix_objects = StixObjects([MARKING, author_identity])
        stix_objects.extend(object_refs.get())
        name = source.get("title") or None
        time_published = source.get("creation_ts") or None
        labels = self._get_malware_families_names(stix_objects)
        if source.get("is_sensitive_source"):
            labels.append(f"{INTEL_471} - sensitive source")
        labels.extend(self._get_girs_labels(source))
        labels.append(PLATFORM_VERITY471)
        description = self._get_description(source) or name
        report_types = [report_type.value]
        if sub_type := source.get("sub_type"):
            report_types.append(sub_type)
        if report_type == ReportType.FINTEL and sub_type == REPORT_SUBTYPE_ACTOR_PROFILE:
            threat_actor = self.entities_mapper.map(**{
                "type": "Handle",
                "value": name,
                "description": description
            })
            stix_objects = StixObjects([i for i in stix_objects.get()
                                        if not (isinstance(i, ThreatActor) and i.name == name)])
            stix_objects.add(threat_actor)
            name = f"Actor Profile - {name}"

        report_kwargs = {
            "id": source["id"],
            "name": name,
            "description": description,
            "report_types": report_types,
            "confidence": self.map_confidence(source.get("assessment", {}).get("admiralty_code") or
                                              source.get("confidence", {}).get("level")),
            "published": time_published,
            "labels": labels,
            "external_references": self._get_external_references(source),
            "object_refs": object_refs.get(),
            "created_by_ref": author_identity,
            "object_marking_refs": [MARKING],
            "custom_properties": {
                "x_intel471_com_uid": source["id"],
                "content": self._get_opencti_content(source)
            }
        }
        if report_type == ReportType.INFOREP:
            if source_reliability := self._map_source_reliability(source.get("assessment", {}).get("admiralty_code")):
                report_kwargs["custom_properties"]["x_opencti_reliability"] = source_reliability
        report = Report(**report_kwargs)
        stix_objects.add(report)
        return stix_objects

    def _fetch_and_map_report(self, report_type: ReportType, report_id: str,
                              object_refs: StixObjects = None) -> StixObjects:
        report_settings = self.reports_settings.get(report_type)
        if report_id not in self.cache:
            api_instance = getattr(self.settings.client,
                                   self.REPORTS_API_CLASS)(self.settings.api_client)
            api_response = getattr(api_instance, report_settings.method_name)(id=report_id, include_inline_images=True)
            self.cache[report_id] = api_response.to_dict()
        return self._map_report(self.cache[report_id], object_refs)

    def _is_full_report_required(self, source: dict) -> bool:
        def _has_inline_images(source: dict):
            pattern = r"^https://api\.intel471\.cloud/intel-report.*/attachments/[a-fA-F0-9]{64}$"
            for item in (source.get('attachments') or []):
                mime_type = item.get("mime_type", "")
                url = item.get("url", "")
                is_image = mime_type.startswith("image/")
                is_valid_url = re.match(pattern, url)
                if is_image and is_valid_url:
                    return True
            return False

        return all([self.settings.report_full_content,
                    self.settings.client,
                    self.settings.api_client,
                    (bool(source.get('is_truncated')) or _has_inline_images(source))])

    def _extract_value(self, source: dict, path_or_extractor_name: str):
        report_type = self._get_type(source)
        report_settings = self.reports_settings.get(report_type)
        path_or_extractor = getattr(report_settings, path_or_extractor_name, "")
        if isinstance(path_or_extractor, Callable):
            try:
                return path_or_extractor(source)
            except Exception as e:
                log.warning("Can't extract value from report %s/%s using path/extractor `%s`. %s",
                            report_type, source["id"], path_or_extractor_name, e)
                return None
        return self._extract_value_by_path(source, path_or_extractor) or None

    @staticmethod
    def _extract_value_by_path(source: dict, path: str):
        for i in path.split("."):
            if not source:
                break
            source = source.get(i, {})
        return source or None

    def _get_external_references(self, source: dict) -> List[ExternalReference]:
        """
        {
            "type": "external",
            "title": "BlogSpot Webpaget: Kelvin Security Team",
            "links": {
            "external": {
                    "href": "http://kelvinsecteam.blogspot.com/"
                }
            },
            "index": 8,
            "last_updated_ts": "2018-08-02T00:00:00Z",
            "source_type": "External Link"
        },

        {
            "type": "internal",
            "title": "Actor Validolik (aka Validol-hack) announces his Android web-injects development service",
            "links": {
            "verity_api": {
                "href": "https://api.intel471.cloud/integrations/intel-report/v1/reports/fintel/report--1a88a0a7-660e-5698-a694-d36bf0c6d4dd"
            },
            "verity_portal": {
                "href": "https://verity.intel471.com/intelligence/infoReportView/report--97ab9a8e-1f33-5765-af67-f2acfe669b9f"
            }
            },
            "index": 1,
            "last_updated_ts": "2017-05-19T00:00:00Z",
            "source_type": "Info Report"
        }
        """
        references = [ExternalReference(source_name="Portal URL", url=self._get_portal_url(source))]
        if value := self._extract_value(source, "links_path"):
            for link_source in value:
                source_name = f"{link_source.get('source_type', link_source.get('type'))} - {link_source['title']}".strip()
                links = [i for i in self.map_links(link_source['links']) if i.type in ("external", "verity_portal")]
                if links:
                    external_ref = ExternalReference(url=links[0].href, source_name=source_name)
                    references.append(external_ref)
        return references

    def _get_entities(self, source: dict) -> StixObjects:
        value = self._extract_value(source, "entities_path_or_extractor")
        stix_objects = StixObjects()
        for entities_source in value or []:
            if entity := self.entities_mapper.map(**entities_source):
                stix_objects.add(entity)
        return stix_objects

    def _get_victims(self, source: dict) -> StixObjects:
        stix_objects = StixObjects()
        if value := self._extract_value(source, "victims_path"):
            if isinstance(value, dict):
                value = [value]
            for victim_src in value:
                uri = None
                if links_src := victim_src.get("links"):
                    external = [i for i in self.map_links(links_src) if i.type == "external"]
                    if external:
                        uri = external[0].href
                stix_objects.add(
                    map_organization(victim_src["name"], uri))
            return stix_objects

    @staticmethod
    def _format_published(epoch_millis: int):
        """
        Formatting datetime object for use as ID contributing property in a same way as it's done
        by OpenCTI to have the same ID here and in OpenCTI.
        """
        parsed = datetime.datetime.fromtimestamp(epoch_millis / 1000, UTC)
        return parsed.strftime("%Y-%m-%dT%H:%M:%S.%f")[:-3] + "Z"

    @staticmethod
    def _get_type(source: dict) -> ReportType:
        type_ = {
            "info_report": ReportType.INFOREP,
            "fintel": ReportType.FINTEL,
            "breach_alert": ReportType.BREACH_ALERT,
            "spot_report": ReportType.SPOTREP,
            "malware_report": ReportType.MALWARE,
            "geopol_report": ReportType.GEOPOL
        }.get(source.get("type"))
        if not type_:
            raise VerityStixException("Unkown report type")
        return type_

    def _get_portal_url(self, source: dict) -> str:
        report_type = self._get_type(source)
        report_id = source["id"]
        report_settings = self.reports_settings.get(report_type)
        return f"https://verity.intel471.com/{report_settings.portal_url_fragment}/{report_id}"

    def _get_girs_labels(self, source: dict) -> List[str]:
        girs_paths = self._extract_value_by_path(source, "classification.girs") or []
        return self.get_girs_labels(girs_paths)

    def _get_description(self, source: dict) -> Union[str, None]:
        value = self._extract_value(source, "description_path_or_extractor")
        if value and isinstance(value, str):
            return re.sub(REMOVE_HTML_REGEX, "", value)

    @staticmethod
    def _get_malware_families_names(entities: StixObjects) -> List[str]:
        return [i.name for i in entities.get() if i.type == "malware"]

    def _get_opencti_content(self, source: dict):
        content_bits = []
        contents_paths = self.reports_settings.get(self._get_type(source)).contents_paths or []
        for path in contents_paths:
            value = self._extract_value_by_path(source, path)
            if value and isinstance(value, str):
                if len(contents_paths) > 1:
                    heading = " ".join([i.capitalize() for i in re.findall(
                        r'[A-Z](?:[a-z]+|[A-Z]*(?=[A-Z]|$))|[a-z]+', path.split(".")[-1])])
                    content_bits.append(f"<h1>{heading}</h1>")
                content_bits.append(value)
        return "\n".join(content_bits)

    def _map_source_reliability(self, admiralty_code: Union[str, None]):
        if admiralty_code and len(admiralty_code) > 0:
            reliability_code = admiralty_code[0].upper()
            return {
                "A": "A - Completely reliable",
                "B": "B - Usually reliable",
                "C": "C - Fairly reliable",
                "D": "D - Not usually reliable",
                "E": "E - Unreliable",
                "F": "F - Reliability cannot be judged"
            }.get(reliability_code)
        return None


# coding: utf-8

# flake8: noqa

"""
    Verity471 Unified API

      - creds: 1.0.1
  - indicators: 1.0.0
  - malware: 1.0.0
  - reports: 1.0.0
  - sources: 1.0.2
  - actors: 1.0.1
  - watchers: 1.0.0
  - observables: 1.0.0
  - entities: 1.0.0
  - girs: 1.0.0


    The version of the OpenAPI document: 1.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.1.1"

# Define package exports
__all__ = [
    "ActorsApi",
    "AlertsApi",
    "CredentialsApi",
    "EventsApi",
    "GIRsApi",
    "IndicatorsApi",
    "MalwareApi",
    "ReportsApi",
    "SourcesApi",
    "WatchersApi",
    "EntitiesApi",
    "ObservablesApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "Activity",
    "ActivityLocation",
    "ActivityResponse",
    "Actor",
    "ActorObject",
    "ActorStreamPage",
    "ActorSubjectOfReport",
    "AdmiraltyCode",
    "AllMalwareProfiles",
    "Assessment",
    "AttachmentClassification",
    "AttachmentData",
    "AuthorActor1",
    "BadRequest",
    "BotSettings",
    "BreachAlertByIdResponse",
    "BreachAlertResponse",
    "BreachAlertsResponseStream",
    "ChatMessageStream",
    "ChatMessagesStreamingPage",
    "ChatRoomMessageStream",
    "ChatServerType",
    "ChatServerTypeStream",
    "Classification",
    "ClassificationResponse",
    "Confidence",
    "ConfidenceLevel",
    "Conflict",
    "ControllerUrl",
    "CountryProfileResponse",
    "CredCredentialSetResponse",
    "CredDataResponse",
    "CredPasswordComplexityResponse",
    "CredPasswordResponse",
    "CredSetAccessedUrlDataResponse",
    "CredSetDataResponse",
    "CredSetStatisticsResponse",
    "CredStatisticsResponse",
    "CredentialOccurrenceCredResponse",
    "CredentialOccurrenceDataResponse",
    "CveSource",
    "Cvss",
    "DataLeakSiteFileListingUrl",
    "DataLeakSitePost1",
    "DataLeakSitePostItem",
    "DataLeakSitePostThread",
    "DataLeakSitePostWebsite",
    "DataLeakSitePostsStreamingPage",
    "Encryption",
    "Entities",
    "Entity",
    "EntityItem",
    "EntityStreamPage",
    "EntityType",
    "ErrorResponse",
    "ErrorResponseGirs",
    "EventController",
    "EventData",
    "EventTag",
    "EventsStream",
    "ExploitStatus",
    "File",
    "FintelReportSubType",
    "FintelReportsResponseStream",
    "FintelResponse",
    "Forbidden",
    "Forum",
    "ForumObject",
    "ForumsPostsStreamingPage",
    "ForumsPrivateMessagesStreamingPage",
    "ForumsResponse1",
    "GIR",
    "GeoIp",
    "GeoIpObservables",
    "GeopolReportDetailsResponse",
    "GeopolReportSubType",
    "GeopolReportsResponseStream",
    "GetCredOccurrenceResponse",
    "GetCredOccurrenceResponseStream",
    "GetCredResponse",
    "GetCredResponseStream",
    "GetCredSetAccessedUrlResponse",
    "GetCredSetAccessedUrlResponseStream",
    "GetCredSetResponse",
    "GetCredSetResponseStream",
    "GetWatcherGroupResponse",
    "GetWatcherGroupResponseWrapper",
    "GetWatcherResponse",
    "GetWatcherResponseWrapper",
    "GirTree",
    "GirsResponse",
    "GirsTreeResponse",
    "Highlight",
    "HighlightWatchers",
    "Href",
    "ImServer",
    "ImageType",
    "IndicatorData",
    "IndicatorsStream",
    "Industries",
    "InfoReportResponse",
    "InfoReportsResponseStream",
    "InfoStealerResponseOption",
    "InfoStealerResponseSet",
    "IntegrationsEvent",
    "IntegrationsIndicator",
    "IntelligenceEstimateResponse",
    "InterestLevel",
    "InternalServerError",
    "Ipv4",
    "Isp",
    "IspData",
    "KillChainPhase",
    "Link",
    "Link1",
    "Links",
    "LinksSource",
    "LinksWatchers",
    "Location",
    "Malware",
    "MalwareFamily",
    "MalwareReportResponse",
    "MalwareReportsResponseStream",
    "Motivation",
    "NotFound",
    "NotificationPreferenceType",
    "NotificationSettingsResponse",
    "Observable",
    "ObservableStreamPage",
    "ObservableType",
    "PatchStatus",
    "Poc",
    "PostDetails1",
    "PostResponse1",
    "PrivateMessageDetails1",
    "PrivateMessageResponse1",
    "ProcessingStatus",
    "RecipientDomain",
    "Redirect",
    "Report",
    "ReportAttachment",
    "ReportContent",
    "ReportEntities",
    "ReportLocation",
    "ReportObservables",
    "ReportResponseStream",
    "ReportType",
    "ReportingStatus",
    "ReportsVictimResponse",
    "Revocation",
    "RiskLevel",
    "RoomStream",
    "SecurityAssessment",
    "ServerStream",
    "Settings",
    "ShareSettingsResponse",
    "SignificantActivity",
    "SimplifiedMalwareProfile",
    "SourceLink",
    "SourceLinks",
    "SourcesLinks",
    "SourcesResponse",
    "SpotReportResponse",
    "SpotReportsResponseStream",
    "StreamingAlertsResponse",
    "StreamingWatcherAlert",
    "SubForumResponse1",
    "Template",
    "TensionPointResponse",
    "ThreadResponse1",
    "Threat",
    "ThreatData",
    "ThreatInfo",
    "ThreatRating",
    "TranslationStatus",
    "Trigger",
    "Unauthorized",
    "VictimResponse",
    "VulnerabilitiesReportDetailsResponse",
    "VulnerabilitiesReportDetailsResponseStream",
    "VulnerabilitiesReportsResponseStream",
    "VulnerabilityStatus",
    "WatcherGroupType",
    "YaraData",
]

# import apis into sdk package
from verity471.api.actors_api import ActorsApi as ActorsApi
from verity471.api.alerts_api import AlertsApi as AlertsApi
from verity471.api.credentials_api import CredentialsApi as CredentialsApi
from verity471.api.events_api import EventsApi as EventsApi
from verity471.api.girs_api import GIRsApi as GIRsApi
from verity471.api.indicators_api import IndicatorsApi as IndicatorsApi
from verity471.api.malware_api import MalwareApi as MalwareApi
from verity471.api.reports_api import ReportsApi as ReportsApi
from verity471.api.sources_api import SourcesApi as SourcesApi
from verity471.api.watchers_api import WatchersApi as WatchersApi
from verity471.api.entities_api import EntitiesApi as EntitiesApi
from verity471.api.observables_api import ObservablesApi as ObservablesApi

# import ApiClient
from verity471.api_response import ApiResponse as ApiResponse
from verity471.api_client import ApiClient as ApiClient
from verity471.configuration import Configuration as Configuration
from verity471.exceptions import OpenApiException as OpenApiException
from verity471.exceptions import ApiTypeError as ApiTypeError
from verity471.exceptions import ApiValueError as ApiValueError
from verity471.exceptions import ApiKeyError as ApiKeyError
from verity471.exceptions import ApiAttributeError as ApiAttributeError
from verity471.exceptions import ApiException as ApiException

# import models into sdk package
from verity471.models.activity import Activity as Activity
from verity471.models.activity_location import ActivityLocation as ActivityLocation
from verity471.models.activity_response import ActivityResponse as ActivityResponse
from verity471.models.actor import Actor as Actor
from verity471.models.actor_object import ActorObject as ActorObject
from verity471.models.actor_stream_page import ActorStreamPage as ActorStreamPage
from verity471.models.actor_subject_of_report import ActorSubjectOfReport as ActorSubjectOfReport
from verity471.models.admiralty_code import AdmiraltyCode as AdmiraltyCode
from verity471.models.all_malware_profiles import AllMalwareProfiles as AllMalwareProfiles
from verity471.models.assessment import Assessment as Assessment
from verity471.models.attachment_classification import AttachmentClassification as AttachmentClassification
from verity471.models.attachment_data import AttachmentData as AttachmentData
from verity471.models.author_actor1 import AuthorActor1 as AuthorActor1
from verity471.models.bad_request import BadRequest as BadRequest
from verity471.models.bot_settings import BotSettings as BotSettings
from verity471.models.breach_alert_by_id_response import BreachAlertByIdResponse as BreachAlertByIdResponse
from verity471.models.breach_alert_response import BreachAlertResponse as BreachAlertResponse
from verity471.models.breach_alerts_response_stream import BreachAlertsResponseStream as BreachAlertsResponseStream
from verity471.models.chat_message_stream import ChatMessageStream as ChatMessageStream
from verity471.models.chat_messages_streaming_page import ChatMessagesStreamingPage as ChatMessagesStreamingPage
from verity471.models.chat_room_message_stream import ChatRoomMessageStream as ChatRoomMessageStream
from verity471.models.chat_server_type import ChatServerType as ChatServerType
from verity471.models.chat_server_type_stream import ChatServerTypeStream as ChatServerTypeStream
from verity471.models.classification import Classification as Classification
from verity471.models.classification_response import ClassificationResponse as ClassificationResponse
from verity471.models.confidence import Confidence as Confidence
from verity471.models.confidence_level import ConfidenceLevel as ConfidenceLevel
from verity471.models.conflict import Conflict as Conflict
from verity471.models.controller_url import ControllerUrl as ControllerUrl
from verity471.models.country_profile_response import CountryProfileResponse as CountryProfileResponse
from verity471.models.cred_credential_set_response import CredCredentialSetResponse as CredCredentialSetResponse
from verity471.models.cred_data_response import CredDataResponse as CredDataResponse
from verity471.models.cred_password_complexity_response import CredPasswordComplexityResponse as CredPasswordComplexityResponse
from verity471.models.cred_password_response import CredPasswordResponse as CredPasswordResponse
from verity471.models.cred_set_accessed_url_data_response import CredSetAccessedUrlDataResponse as CredSetAccessedUrlDataResponse
from verity471.models.cred_set_data_response import CredSetDataResponse as CredSetDataResponse
from verity471.models.cred_set_statistics_response import CredSetStatisticsResponse as CredSetStatisticsResponse
from verity471.models.cred_statistics_response import CredStatisticsResponse as CredStatisticsResponse
from verity471.models.credential_occurrence_cred_response import CredentialOccurrenceCredResponse as CredentialOccurrenceCredResponse
from verity471.models.credential_occurrence_data_response import CredentialOccurrenceDataResponse as CredentialOccurrenceDataResponse
from verity471.models.cve_source import CveSource as CveSource
from verity471.models.cvss import Cvss as Cvss
from verity471.models.data_leak_site_file_listing_url import DataLeakSiteFileListingUrl as DataLeakSiteFileListingUrl
from verity471.models.data_leak_site_post1 import DataLeakSitePost1 as DataLeakSitePost1
from verity471.models.data_leak_site_post_item import DataLeakSitePostItem as DataLeakSitePostItem
from verity471.models.data_leak_site_post_thread import DataLeakSitePostThread as DataLeakSitePostThread
from verity471.models.data_leak_site_post_website import DataLeakSitePostWebsite as DataLeakSitePostWebsite
from verity471.models.data_leak_site_posts_streaming_page import DataLeakSitePostsStreamingPage as DataLeakSitePostsStreamingPage
from verity471.models.encryption import Encryption as Encryption
from verity471.models.entities import Entities as Entities
from verity471.models.entity import Entity as Entity
from verity471.models.entity_item import EntityItem as EntityItem
from verity471.models.entity_stream_page import EntityStreamPage as EntityStreamPage
from verity471.models.entity_type import EntityType as EntityType
from verity471.models.error_response import ErrorResponse as ErrorResponse
from verity471.models.error_response_girs import ErrorResponseGirs as ErrorResponseGirs
from verity471.models.event_controller import EventController as EventController
from verity471.models.event_data import EventData as EventData
from verity471.models.event_tag import EventTag as EventTag
from verity471.models.events_stream import EventsStream as EventsStream
from verity471.models.exploit_status import ExploitStatus as ExploitStatus
from verity471.models.file import File as File
from verity471.models.fintel_report_sub_type import FintelReportSubType as FintelReportSubType
from verity471.models.fintel_reports_response_stream import FintelReportsResponseStream as FintelReportsResponseStream
from verity471.models.fintel_response import FintelResponse as FintelResponse
from verity471.models.forbidden import Forbidden as Forbidden
from verity471.models.forum import Forum as Forum
from verity471.models.forum_object import ForumObject as ForumObject
from verity471.models.forums_posts_streaming_page import ForumsPostsStreamingPage as ForumsPostsStreamingPage
from verity471.models.forums_private_messages_streaming_page import ForumsPrivateMessagesStreamingPage as ForumsPrivateMessagesStreamingPage
from verity471.models.forums_response1 import ForumsResponse1 as ForumsResponse1
from verity471.models.gir import GIR as GIR
from verity471.models.geo_ip import GeoIp as GeoIp
from verity471.models.geo_ip_observables import GeoIpObservables as GeoIpObservables
from verity471.models.geopol_report_details_response import GeopolReportDetailsResponse as GeopolReportDetailsResponse
from verity471.models.geopol_report_sub_type import GeopolReportSubType as GeopolReportSubType
from verity471.models.geopol_reports_response_stream import GeopolReportsResponseStream as GeopolReportsResponseStream
from verity471.models.get_cred_occurrence_response import GetCredOccurrenceResponse as GetCredOccurrenceResponse
from verity471.models.get_cred_occurrence_response_stream import GetCredOccurrenceResponseStream as GetCredOccurrenceResponseStream
from verity471.models.get_cred_response import GetCredResponse as GetCredResponse
from verity471.models.get_cred_response_stream import GetCredResponseStream as GetCredResponseStream
from verity471.models.get_cred_set_accessed_url_response import GetCredSetAccessedUrlResponse as GetCredSetAccessedUrlResponse
from verity471.models.get_cred_set_accessed_url_response_stream import GetCredSetAccessedUrlResponseStream as GetCredSetAccessedUrlResponseStream
from verity471.models.get_cred_set_response import GetCredSetResponse as GetCredSetResponse
from verity471.models.get_cred_set_response_stream import GetCredSetResponseStream as GetCredSetResponseStream
from verity471.models.get_watcher_group_response import GetWatcherGroupResponse as GetWatcherGroupResponse
from verity471.models.get_watcher_group_response_wrapper import GetWatcherGroupResponseWrapper as GetWatcherGroupResponseWrapper
from verity471.models.get_watcher_response import GetWatcherResponse as GetWatcherResponse
from verity471.models.get_watcher_response_wrapper import GetWatcherResponseWrapper as GetWatcherResponseWrapper
from verity471.models.gir_tree import GirTree as GirTree
from verity471.models.girs_response import GirsResponse as GirsResponse
from verity471.models.girs_tree_response import GirsTreeResponse as GirsTreeResponse
from verity471.models.highlight import Highlight as Highlight
from verity471.models.highlight_watchers import HighlightWatchers as HighlightWatchers
from verity471.models.href import Href as Href
from verity471.models.im_server import ImServer as ImServer
from verity471.models.image_type import ImageType as ImageType
from verity471.models.indicator_data import IndicatorData as IndicatorData
from verity471.models.indicators_stream import IndicatorsStream as IndicatorsStream
from verity471.models.industries import Industries as Industries
from verity471.models.info_report_response import InfoReportResponse as InfoReportResponse
from verity471.models.info_reports_response_stream import InfoReportsResponseStream as InfoReportsResponseStream
from verity471.models.info_stealer_response_option import InfoStealerResponseOption as InfoStealerResponseOption
from verity471.models.info_stealer_response_set import InfoStealerResponseSet as InfoStealerResponseSet
from verity471.models.integrations_event import IntegrationsEvent as IntegrationsEvent
from verity471.models.integrations_indicator import IntegrationsIndicator as IntegrationsIndicator
from verity471.models.intelligence_estimate_response import IntelligenceEstimateResponse as IntelligenceEstimateResponse
from verity471.models.interest_level import InterestLevel as InterestLevel
from verity471.models.internal_server_error import InternalServerError as InternalServerError
from verity471.models.ipv4 import Ipv4 as Ipv4
from verity471.models.isp import Isp as Isp
from verity471.models.isp_data import IspData as IspData
from verity471.models.kill_chain_phase import KillChainPhase as KillChainPhase
from verity471.models.link import Link as Link
from verity471.models.link1 import Link1 as Link1
from verity471.models.links import Links as Links
from verity471.models.links_source import LinksSource as LinksSource
from verity471.models.links_watchers import LinksWatchers as LinksWatchers
from verity471.models.location import Location as Location
from verity471.models.malware import Malware as Malware
from verity471.models.malware_family import MalwareFamily as MalwareFamily
from verity471.models.malware_report_response import MalwareReportResponse as MalwareReportResponse
from verity471.models.malware_reports_response_stream import MalwareReportsResponseStream as MalwareReportsResponseStream
from verity471.models.motivation import Motivation as Motivation
from verity471.models.not_found import NotFound as NotFound
from verity471.models.notification_preference_type import NotificationPreferenceType as NotificationPreferenceType
from verity471.models.notification_settings_response import NotificationSettingsResponse as NotificationSettingsResponse
from verity471.models.observable import Observable as Observable
from verity471.models.observable_stream_page import ObservableStreamPage as ObservableStreamPage
from verity471.models.observable_type import ObservableType as ObservableType
from verity471.models.patch_status import PatchStatus as PatchStatus
from verity471.models.poc import Poc as Poc
from verity471.models.post_details1 import PostDetails1 as PostDetails1
from verity471.models.post_response1 import PostResponse1 as PostResponse1
from verity471.models.private_message_details1 import PrivateMessageDetails1 as PrivateMessageDetails1
from verity471.models.private_message_response1 import PrivateMessageResponse1 as PrivateMessageResponse1
from verity471.models.processing_status import ProcessingStatus as ProcessingStatus
from verity471.models.recipient_domain import RecipientDomain as RecipientDomain
from verity471.models.redirect import Redirect as Redirect
from verity471.models.report import Report as Report
from verity471.models.report_attachment import ReportAttachment as ReportAttachment
from verity471.models.report_content import ReportContent as ReportContent
from verity471.models.report_entities import ReportEntities as ReportEntities
from verity471.models.report_location import ReportLocation as ReportLocation
from verity471.models.report_observables import ReportObservables as ReportObservables
from verity471.models.report_response_stream import ReportResponseStream as ReportResponseStream
from verity471.models.report_type import ReportType as ReportType
from verity471.models.reporting_status import ReportingStatus as ReportingStatus
from verity471.models.reports_victim_response import ReportsVictimResponse as ReportsVictimResponse
from verity471.models.revocation import Revocation as Revocation
from verity471.models.risk_level import RiskLevel as RiskLevel
from verity471.models.room_stream import RoomStream as RoomStream
from verity471.models.security_assessment import SecurityAssessment as SecurityAssessment
from verity471.models.server_stream import ServerStream as ServerStream
from verity471.models.settings import Settings as Settings
from verity471.models.share_settings_response import ShareSettingsResponse as ShareSettingsResponse
from verity471.models.significant_activity import SignificantActivity as SignificantActivity
from verity471.models.simplified_malware_profile import SimplifiedMalwareProfile as SimplifiedMalwareProfile
from verity471.models.source_link import SourceLink as SourceLink
from verity471.models.source_links import SourceLinks as SourceLinks
from verity471.models.sources_links import SourcesLinks as SourcesLinks
from verity471.models.sources_response import SourcesResponse as SourcesResponse
from verity471.models.spot_report_response import SpotReportResponse as SpotReportResponse
from verity471.models.spot_reports_response_stream import SpotReportsResponseStream as SpotReportsResponseStream
from verity471.models.streaming_alerts_response import StreamingAlertsResponse as StreamingAlertsResponse
from verity471.models.streaming_watcher_alert import StreamingWatcherAlert as StreamingWatcherAlert
from verity471.models.sub_forum_response1 import SubForumResponse1 as SubForumResponse1
from verity471.models.template import Template as Template
from verity471.models.tension_point_response import TensionPointResponse as TensionPointResponse
from verity471.models.thread_response1 import ThreadResponse1 as ThreadResponse1
from verity471.models.threat import Threat as Threat
from verity471.models.threat_data import ThreatData as ThreatData
from verity471.models.threat_info import ThreatInfo as ThreatInfo
from verity471.models.threat_rating import ThreatRating as ThreatRating
from verity471.models.translation_status import TranslationStatus as TranslationStatus
from verity471.models.trigger import Trigger as Trigger
from verity471.models.unauthorized import Unauthorized as Unauthorized
from verity471.models.victim_response import VictimResponse as VictimResponse
from verity471.models.vulnerabilities_report_details_response import VulnerabilitiesReportDetailsResponse as VulnerabilitiesReportDetailsResponse
from verity471.models.vulnerabilities_report_details_response_stream import VulnerabilitiesReportDetailsResponseStream as VulnerabilitiesReportDetailsResponseStream
from verity471.models.vulnerabilities_reports_response_stream import VulnerabilitiesReportsResponseStream as VulnerabilitiesReportsResponseStream
from verity471.models.vulnerability_status import VulnerabilityStatus as VulnerabilityStatus
from verity471.models.watcher_group_type import WatcherGroupType as WatcherGroupType
from verity471.models.yara_data import YaraData as YaraData




from verity471.verity_stix.mappers.cves import CveMapper
from verity471.verity_stix.mappers.indicators import IndicatorsMapper
from verity471.verity_stix.mappers.reports import ReportMapper


__all__ = [
    "CveMapper",
    "IndicatorsMapper",
    "ReportMapper"
]



# coding: utf-8

"""
    Verity471 Unified API

      - creds: 1.0.1
  - indicators: 1.0.0
  - malware: 1.0.0
  - reports: 1.0.0
  - sources: 1.0.2
  - actors: 1.0.1
  - watchers: 1.0.0
  - observables: 1.0.0
  - entities: 1.0.0
  - girs: 1.0.0


    The version of the OpenAPI document: 1.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from verity471.models.streaming_alerts_response import StreamingAlertsResponse

from verity471.api_client import ApiClient, RequestSerialized
from verity471.api_response import ApiResponse
from verity471.rest import RESTResponseType


class AlertsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_alerts_stream(
        self,
        cursor: Annotated[Optional[StrictStr], Field(description="Cursor to be used to fetch next batch from stream")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Size of the batch to return. Defaults to 1000. Max value 1000 (if size is bigger than this onlyfirst 1000 alerts will be returned)")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="Long unix time. Example - 1627776000000 (By timestamp)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="Long unix time. Example - 1627776000000 (By timestamp)")] = None,
        watcher_group_ids: Annotated[Optional[StrictStr], Field(description="Comma separated watcher group ids to filter alerts.")] = None,
        watcher_ids: Annotated[Optional[StrictStr], Field(description="Comma separated watcher ids to filter alerts.")] = None,
        statuses: Annotated[Optional[StrictStr], Field(description="Comma separated statuses to filter alerts. Allowed values are generated, needs_action, in_progress, completed and false_positive.")] = None,
        is_trashed_included: Annotated[Optional[StrictBool], Field(description="Include trashed alerts in the response. Defaults to false.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> StreamingAlertsResponse:
        """Get alerts for the current user in a stream way


        :param cursor: Cursor to be used to fetch next batch from stream
        :type cursor: str
        :param size: Size of the batch to return. Defaults to 1000. Max value 1000 (if size is bigger than this onlyfirst 1000 alerts will be returned)
        :type size: int
        :param var_from: Long unix time. Example - 1627776000000 (By timestamp)
        :type var_from: int
        :param until: Long unix time. Example - 1627776000000 (By timestamp)
        :type until: int
        :param watcher_group_ids: Comma separated watcher group ids to filter alerts.
        :type watcher_group_ids: str
        :param watcher_ids: Comma separated watcher ids to filter alerts.
        :type watcher_ids: str
        :param statuses: Comma separated statuses to filter alerts. Allowed values are generated, needs_action, in_progress, completed and false_positive.
        :type statuses: str
        :param is_trashed_included: Include trashed alerts in the response. Defaults to false.
        :type is_trashed_included: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_alerts_stream_serialize(
            cursor=cursor,
            size=size,
            var_from=var_from,
            until=until,
            watcher_group_ids=watcher_group_ids,
            watcher_ids=watcher_ids,
            statuses=statuses,
            is_trashed_included=is_trashed_included,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StreamingAlertsResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_alerts_stream_with_http_info(
        self,
        cursor: Annotated[Optional[StrictStr], Field(description="Cursor to be used to fetch next batch from stream")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Size of the batch to return. Defaults to 1000. Max value 1000 (if size is bigger than this onlyfirst 1000 alerts will be returned)")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="Long unix time. Example - 1627776000000 (By timestamp)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="Long unix time. Example - 1627776000000 (By timestamp)")] = None,
        watcher_group_ids: Annotated[Optional[StrictStr], Field(description="Comma separated watcher group ids to filter alerts.")] = None,
        watcher_ids: Annotated[Optional[StrictStr], Field(description="Comma separated watcher ids to filter alerts.")] = None,
        statuses: Annotated[Optional[StrictStr], Field(description="Comma separated statuses to filter alerts. Allowed values are generated, needs_action, in_progress, completed and false_positive.")] = None,
        is_trashed_included: Annotated[Optional[StrictBool], Field(description="Include trashed alerts in the response. Defaults to false.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[StreamingAlertsResponse]:
        """Get alerts for the current user in a stream way


        :param cursor: Cursor to be used to fetch next batch from stream
        :type cursor: str
        :param size: Size of the batch to return. Defaults to 1000. Max value 1000 (if size is bigger than this onlyfirst 1000 alerts will be returned)
        :type size: int
        :param var_from: Long unix time. Example - 1627776000000 (By timestamp)
        :type var_from: int
        :param until: Long unix time. Example - 1627776000000 (By timestamp)
        :type until: int
        :param watcher_group_ids: Comma separated watcher group ids to filter alerts.
        :type watcher_group_ids: str
        :param watcher_ids: Comma separated watcher ids to filter alerts.
        :type watcher_ids: str
        :param statuses: Comma separated statuses to filter alerts. Allowed values are generated, needs_action, in_progress, completed and false_positive.
        :type statuses: str
        :param is_trashed_included: Include trashed alerts in the response. Defaults to false.
        :type is_trashed_included: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_alerts_stream_serialize(
            cursor=cursor,
            size=size,
            var_from=var_from,
            until=until,
            watcher_group_ids=watcher_group_ids,
            watcher_ids=watcher_ids,
            statuses=statuses,
            is_trashed_included=is_trashed_included,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StreamingAlertsResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_alerts_stream_without_preload_content(
        self,
        cursor: Annotated[Optional[StrictStr], Field(description="Cursor to be used to fetch next batch from stream")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Size of the batch to return. Defaults to 1000. Max value 1000 (if size is bigger than this onlyfirst 1000 alerts will be returned)")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="Long unix time. Example - 1627776000000 (By timestamp)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="Long unix time. Example - 1627776000000 (By timestamp)")] = None,
        watcher_group_ids: Annotated[Optional[StrictStr], Field(description="Comma separated watcher group ids to filter alerts.")] = None,
        watcher_ids: Annotated[Optional[StrictStr], Field(description="Comma separated watcher ids to filter alerts.")] = None,
        statuses: Annotated[Optional[StrictStr], Field(description="Comma separated statuses to filter alerts. Allowed values are generated, needs_action, in_progress, completed and false_positive.")] = None,
        is_trashed_included: Annotated[Optional[StrictBool], Field(description="Include trashed alerts in the response. Defaults to false.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get alerts for the current user in a stream way


        :param cursor: Cursor to be used to fetch next batch from stream
        :type cursor: str
        :param size: Size of the batch to return. Defaults to 1000. Max value 1000 (if size is bigger than this onlyfirst 1000 alerts will be returned)
        :type size: int
        :param var_from: Long unix time. Example - 1627776000000 (By timestamp)
        :type var_from: int
        :param until: Long unix time. Example - 1627776000000 (By timestamp)
        :type until: int
        :param watcher_group_ids: Comma separated watcher group ids to filter alerts.
        :type watcher_group_ids: str
        :param watcher_ids: Comma separated watcher ids to filter alerts.
        :type watcher_ids: str
        :param statuses: Comma separated statuses to filter alerts. Allowed values are generated, needs_action, in_progress, completed and false_positive.
        :type statuses: str
        :param is_trashed_included: Include trashed alerts in the response. Defaults to false.
        :type is_trashed_included: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_alerts_stream_serialize(
            cursor=cursor,
            size=size,
            var_from=var_from,
            until=until,
            watcher_group_ids=watcher_group_ids,
            watcher_ids=watcher_ids,
            statuses=statuses,
            is_trashed_included=is_trashed_included,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StreamingAlertsResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_alerts_stream_serialize(
        self,
        cursor,
        size,
        var_from,
        until,
        watcher_group_ids,
        watcher_ids,
        statuses,
        is_trashed_included,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if var_from is not None:
            
            _query_params.append(('from', var_from))
            
        if until is not None:
            
            _query_params.append(('until', until))
            
        if watcher_group_ids is not None:
            
            _query_params.append(('watcher_group_ids', watcher_group_ids))
            
        if watcher_ids is not None:
            
            _query_params.append(('watcher_ids', watcher_ids))
            
        if statuses is not None:
            
            _query_params.append(('statuses', statuses))
            
        if is_trashed_included is not None:
            
            _query_params.append(('is_trashed_included', is_trashed_included))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/watchers/v1/alerts/stream',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def put_alerts_id_status(
        self,
        id: StrictInt,
        status: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Change status of an alert


        :param id: (required)
        :type id: int
        :param status: (required)
        :type status: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_alerts_id_status_serialize(
            id=id,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def put_alerts_id_status_with_http_info(
        self,
        id: StrictInt,
        status: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Change status of an alert


        :param id: (required)
        :type id: int
        :param status: (required)
        :type status: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_alerts_id_status_serialize(
            id=id,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def put_alerts_id_status_without_preload_content(
        self,
        id: StrictInt,
        status: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Change status of an alert


        :param id: (required)
        :type id: int
        :param status: (required)
        :type status: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_alerts_id_status_serialize(
            id=id,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _put_alerts_id_status_serialize(
        self,
        id,
        status,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if status is not None:
            _path_params['status'] = status
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/integrations/watchers/v1/alerts/{id}/{status}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Verity471 Unified API

      - creds: 1.0.1
  - indicators: 1.0.0
  - malware: 1.0.0
  - reports: 1.0.0
  - sources: 1.0.2
  - actors: 1.0.1
  - watchers: 1.0.0
  - observables: 1.0.0
  - entities: 1.0.0
  - girs: 1.0.0


    The version of the OpenAPI document: 1.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class EntityType(str, Enum):
    """
    EntityType
    """

    """
    allowed enum values
    """
    AIM = 'AIM'
    ACTORDOMAIN = 'ActorDomain'
    BITCOINADDRESS = 'BitcoinAddress'
    BITCOINTRANSACTIONID = 'BitcoinTransactionID'
    CVEID = 'CveID'
    OTHERCRYPTOCURRENCIES = 'OtherCryptoCurrencies'
    EMAILADDRESS = 'EmailAddress'
    FACEBOOK = 'Facebook'
    HANDLE = 'Handle'
    ICQ = 'ICQ'
    IPV4PREFIX = 'IPv4Prefix'
    IPV6PREFIX = 'IPv6Prefix'
    JABBER = 'Jabber'
    MSN = 'MSN'
    MALWAREFAMILY = 'MalwareFamily'
    MOBILEMALWAREFAMILY = 'MobileMalwareFamily'
    PERFECTMONEYID = 'PerfectMoneyID'
    PHONE = 'Phone'
    QQ = 'QQ'
    QIWIWALLET = 'QiwiWallet'
    SKYPE = 'Skype'
    TWITTER = 'Twitter'
    X = 'X'
    URL = 'URL'
    VK = 'VK'
    WEBMONEYID = 'WebMoneyID'
    WEBMONEYPURSE = 'WebMoneyPurse'
    YAHOOIM = 'YahooIM'
    YANDEXMONEY = 'YandexMoney'
    TELEGRAM = 'Telegram'
    TAG = 'Tag'
    TOX = 'Tox'
    PASSWORDHASH = 'PasswordHash'
    PASSWORD = 'Password'
    PGPKEY = 'PGPKey'
    PGPKEYID = 'PGPKeyID'
    ACTOROTHERWEBSITE = 'ActorOtherWebsite'
    ODNOKLASSNIKI = 'Odnoklassniki'
    MOIMIR = 'MoiMir'
    INSTAGRAM = 'Instagram'
    LINKEDIN = 'LinkedIn'
    GITHUB = 'GitHub'
    DISCORD = 'Discord'
    WECHAT = 'WeChat'
    WICKR = 'Wickr'
    SIGNAL = 'Signal'
    IPADDRESS = 'IPAddress'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of EntityType from a JSON string"""
        return cls(json.loads(json_str))


